==> moodle_1.3.1.orig.tar.gz: moodle/lang/fr/assignment.php <==
<?PHP // $Id: assignment.php,v 1.8 2004/02/04 21:59:08 martignoni Exp $ 


$string['allowresubmit'] = 'Permettre plusieurs remises d\'un devoir';
$string['assignmentdetails'] = 'Dtails du devoir';
$string['assignmentmail'] = '$a->teacher a envoy un feedback concernant votre devoir  $a->assignment 

Vous pouvez le consulter en annexe  votre devoir:

$a->url';
$string['assignmentmailhtml'] = '$a->teacher a envoy un feedback concernant votre devoir rendu  <i>$a->assignment</i> <br /><br />

Vous pouvez le consulter en annexe  <a href=\'$a->url\'>votre devoir</a>.';
$string['assignmentname'] = 'Nom du devoir';
$string['assignmenttype'] = 'Type du devoir';
$string['configmaxbytes'] = 'Taille maximale par dfaut de tous les devoirs du site (sujet aux limites des cours et autres rglages locaux)';
$string['description'] = 'Description';
$string['duedate'] = ' rendre le';
$string['duedateno'] = 'Pas de date de retour';
$string['early'] = 'en avance de $a';
$string['existingfiledeleted'] = 'Le fichier $a a t supprim';
$string['failedupdatefeedback'] = 'Impossible d\'enregistrer le feedback pour $a';
$string['feedback'] = 'Feedback';
$string['feedbackupdated'] = 'Feedback enregistr pour $a utilisateurs';
$string['late'] = 'en retard de $a';
$string['maximumgrade'] = 'Note maximale';
$string['maximumsize'] = 'Taille maximale';
$string['modulename'] = 'Devoir';
$string['modulenameplural'] = 'Devoirs';
$string['newsubmissions'] = 'Devoirs rendus';
$string['notgradedyet'] = 'Pas encore de note';
$string['notsubmittedyet'] = 'Pas encore rendu';
$string['overwritewarning'] = 'Attention : un nouvel envoi remplacera votre devoir dj remis';
$string['saveallfeedback'] = 'Enregistrer tous mes feedbacks';
$string['submissionfeedback'] = 'Feedback du devoir';
$string['submissions'] = 'Devoirs rendus';
$string['submitassignment'] = 'Envoyer votre devoir en utilisant ce formulaire';
$string['submitted'] = 'Devoir rendu';
$string['typeoffline'] = 'Activit hors ligne';
$string['typeuploadsingle'] = 'Envoyer un fichier';
$string['uploadbadname'] = 'Ce nom de fichier contient d\'tranges caractres. Il ne peut tre envoy';
$string['uploadedfiles'] = 'fichiers envoys';
$string['uploaderror'] = 'Une erreur est survenue lors de l\'enregistrement du fichier sur le serveur';
$string['uploadfailnoupdate'] = 'Le fichier a t correctement envoy, mais il n\'a pas t possible de mettre  jour votre devoir !';
$string['uploadfiletoobig'] = 'Dsol, la taille de ce fichier est trop grande (taille maximale: $a octets)';
$string['uploadnofilefound'] = 'Aucun fichier n\'a t trouv, tes-vous certain d\'en avoir choisi un  envoyer ?';
$string['uploadnotregistered'] = ' $a  a t correctement envoy mais votre devoir n\'a pu tre enregistr !';
$string['uploadsuccess'] = ' $a  a t correctement envoy';
$string['viewfeedback'] = 'Afficher les notes et feedbacks des devoirs';
$string['viewsubmissions'] = 'Afficher les $a devoirs rendus';
$string['yoursubmission'] = 'Votre devoir';

?>

==> moodle_1.4.4.dfsg.1.orig.tar.gz: moodle/lang/fr/assignment.php <==
<?php // $Id$ 

$string['allowresubmit'] = 'Permettre plusieurs remises d\'un devoir';
$string['assignmentdetails'] = 'Dtails du devoir';
$string['assignmentmail'] = '$a->teacher a crit un feedback concernant votre devoir  $a->assignment 

Vous pouvez le consulter en annexe  votre devoir:

$a->url';
$string['assignmentmailhtml'] = '$a->teacher a crit un feedback concernant votre devoir rendu  <em>$a->assignment</em> <br /><br />

Vous pouvez le consulter en annexe  <a href=\'$a->url\'>votre devoir</a>.';
$string['assignmentname'] = 'Nom du devoir';
$string['assignmenttype'] = 'Type du devoir';
$string['configmaxbytes'] = 'Taille maximale par dfaut de tous les devoirs du site (sujet aux limites des cours et autres rglages locaux)';
$string['description'] = 'Description';
$string['duedate'] = ' rendre le';
$string['duedateno'] = 'Pas de date de retour';
$string['early'] = 'en avance de $a';
$string['existingfiledeleted'] = 'Le fichier $a a t supprim';
$string['failedupdatefeedback'] = 'Impossible d\'enregistrer le feedback pour $a';
$string['feedback'] = 'Feedback';
$string['feedbackupdated'] = 'Feedback enregistr pour $a utilisateurs';
$string['late'] = 'en retard de $a';
$string['maximumgrade'] = 'Note maximale';
$string['maximumsize'] = 'Taille maximale';
$string['modulename'] = 'Devoir';
$string['modulenameplural'] = 'Devoirs';
$string['newsubmissions'] = 'Devoirs rendus';
$string['notgradedyet'] = 'Pas encore de note';
$string['notsubmittedyet'] = 'Pas encore rendu';
$string['overwritewarning'] = 'Attention ! un nouvel envoi remplacera votre devoir dj remis';
$string['saveallfeedback'] = 'Enregistrer tous mes feedbacks';
$string['submissionfeedback'] = 'Feedback du devoir';
$string['submissions'] = 'Devoirs rendus';
$string['submitassignment'] = 'Dposer votre devoir en utilisant ce formulaire';
$string['submitted'] = 'Devoir rendu';
$string['typeoffline'] = 'Activit hors ligne';
$string['typeuploadsingle'] = 'Dposer un fichier';
$string['uploadbadname'] = 'Ce nom de fichier contient d\'tranges caractres. Il ne peut tre dpos';
$string['uploadedfiles'] = 'fichiers dposs';
$string['uploaderror'] = 'Une erreur est survenue lors de l\'enregistrement du fichier sur le serveur';
$string['uploadfailnoupdate'] = 'Le fichier a t correctement dpos, mais il n\'a pas t possible de mettre  jour votre devoir !';
$string['uploadfiletoobig'] = 'Dsol, la taille de ce fichier est trop grande (taille maximale: $a octets)';
$string['uploadnofilefound'] = 'Aucun fichier n\'a t trouv, tes-vous certain d\'en avoir choisi un  dposer ?';
$string['uploadnotregistered'] = ' $a  a t correctement dpos, mais votre devoir n\'a pu tre enregistr !';
$string['uploadsuccess'] = ' $a  a t correctement dpos';
$string['viewfeedback'] = 'Afficher les notes et feedbacks des devoirs';
$string['viewsubmissions'] = 'Afficher les $a devoirs rendus';
$string['yoursubmission'] = 'Votre devoir';

?>
